@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1998 Steve Borho <steve@borho.myip.org>
+** Copyright (C) 1998 Steve Borho <steve@borho.org>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -120,7 +120,7 @@ void            ejectDrive(MPInfo * mp)
         char            cmd[256];
         int             n = (sizeof(cmd) / sizeof(cmd[0]));
        
-        snprintf(cmd, n, ejectcmd, mp->devStr);
+        snprintf(cmd, n, ejectcmd, mp->mountStr);
         cmd[n - 1] = '\0';
         newSystem(cmd, mp);
     }
