@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1998 Steve Borho <steve@borho.myip.org>
+** Copyright (C) 1998 Steve Borho <steve@borho.org>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@ void            parseFstab(allInfo * ai)
             continue;
 
         /* If the drive is user mountable, don't show capacity */
-        if (strstr(tok, "user") != NULL)
+        if (strstr(tok, "user") != NULL || strstr(tok, "owner") != NULL)
             ai->mpi[nm - 1]->showCap = CAPACITY_NONE;
         else if (userOnly)
             ai->mpi[nm - 1]->ignored = TRUE;
