@@ -1,5 +1,5 @@
 /* mount.h
-   // Copyright (C) 1998 by Steve Borho <steve@borho.myip.org>
+   // Copyright (C) 1998 by Steve Borho <steve@borho.org>
    // This software comes with ABSOLUTELY NO WARRANTY
    // This software is free software, and you are welcome to redistribute it
    // under certain conditions
@@ -42,7 +42,7 @@
 #include <X11/xpm.h>
 #include <X11/extensions/shape.h>
 
-#include <proplist.h>
+#include <WINGs/WINGs.h>
 
 typedef unsigned char bool;
 
@@ -177,9 +177,9 @@ void            initializeAppIcon(void);
 
 /* Mount point detection and properties stuff */
 void            parseFstab(allInfo *);
-bool            loadPropString(proplist_t, char *, char *, size_t);
+bool            loadPropString(WMPropList *, char *, char *, size_t);
 void            readProperties(allInfo *);
-bool            savePropString(proplist_t, char *, char *, size_t);
+bool            savePropString(WMPropList *, char *, char *, size_t);
 void            saveProperties(allInfo *);
 
 /* Special stuff */
