@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1998 Steve Borho <steve@borho.myip.org>
+** Copyright (C) 1998 Steve Borho <steve@borho.org>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,25 +25,25 @@ static int      createDefaultPropertiesFile(allInfo *ai);
 static int      makeRecursivePath(char *path);
 
 bool            loadPropString(
-        proplist_t p,
+        WMPropList *p,
         char *key,
         char *valbuf,
         size_t valbuf_size)
 {
-    proplist_t keyProp, valProp;
-    bool string_found = NO;
+    WMPropList *keyProp, *valProp;
+    bool string_found = FALSE;
 
-    keyProp = PLMakeString(key);
+    keyProp = WMCreatePLString(key);
     if (keyProp)
     {
-        valProp = PLGetDictionaryEntry(p, keyProp);
-        if (valProp && PLIsString(valProp))
+        valProp = WMGetFromPLDictionary(p, keyProp);
+        if (valProp && WMIsPLString(valProp))
         {
-            safeCopy(valbuf, PLGetString(valProp), valbuf_size);
-            string_found = YES;
+            safeCopy(valbuf, WMGetFromPLString(valProp), valbuf_size);
+            string_found = TRUE;
         }
 
-        PLRelease(keyProp);
+        WMReleasePropList(keyProp);
     }
 
     return string_found;
@@ -53,15 +53,15 @@ void            readProperties(allInfo *ai)
 {
     char        buf[256];
     int         cur_mp;
-    proplist_t  props;
+    WMPropList  *props;
     struct MPInfo  *mp;
 
-    props = PLGetProplistWithPath(getFileName());
+    props = WMReadPropListFromFile(getFileName());
     if (props == NULL)
     {
         if (createDefaultPropertiesFile(ai))
         {
-            props = PLGetProplistWithPath(getFileName());
+            props = WMReadPropListFromFile(getFileName());
             firstTimeUser = TRUE;
         }
         else
@@ -133,17 +133,17 @@ void            readProperties(allInfo *ai)
 
     for (cur_mp = 0; cur_mp < ai->numMounts; cur_mp++)
     {
-        proplist_t nameProp, mpProp;
+        WMPropList *nameProp, *mpProp;
 
         mp = ai->mpi[cur_mp];
         sprintf(buf, "mountpoint.%s", mp->mountStr);
 
-        nameProp = PLMakeString(buf);
+        nameProp = WMCreatePLString(buf);
         if (nameProp == NULL)
             continue;
 
-        mpProp = PLGetDictionaryEntry(props, nameProp);
-        if (mpProp && PLIsDictionary(mpProp))
+        mpProp = WMGetFromPLDictionary(props, nameProp);
+        if (mpProp && WMIsPLDictionary(mpProp))
         {
             loadPropString(mpProp, "mountname", mp->name, NAME_LEN);
             if (loadPropString(mpProp, "icontype", buf, sizeof(buf)))
@@ -201,45 +201,45 @@ void            readProperties(allInfo *ai)
             }
 
         }
-        PLRelease(nameProp);
+        WMReleasePropList(nameProp);
     }
 
-    PLRelease(props);
+    WMReleasePropList(props);
 }
 
 bool            savePropString(
-        proplist_t p,
+        WMPropList *p,
         char *key,
         char *valbuf,
         size_t valbuf_size)
 {
-    proplist_t keyProp, valProp;
-    bool string_found = NO;
+    WMPropList *keyProp, *valProp;
+    bool string_found = FALSE;
 
-    keyProp = PLMakeString(key);
+    keyProp = WMCreatePLString(key);
     if (keyProp)
     {
-        valProp = PLGetDictionaryEntry(p, keyProp);
-        if (valProp && PLIsString(valProp))
+        valProp = WMGetFromPLDictionary(p, keyProp);
+        if (valProp && WMIsPLString(valProp))
         {
             string_found = TRUE;
-            if (strcmp(valbuf, PLGetString(valProp)) == 0)
+            if (strcmp(valbuf, WMGetFromPLString(valProp)) == 0)
             {
-                PLRelease(keyProp);
+                WMReleasePropList(keyProp);
                 return string_found;
             }
 
-            PLRemoveDictionaryEntry(p, keyProp);
+            WMRemoveFromPLDictionary(p, keyProp);
         }
 
         if (*valbuf)
         {
-            valProp = PLMakeString(valbuf);
-            PLInsertDictionaryEntry(p, keyProp, valProp);
-            PLRelease(valProp);
+            valProp = WMCreatePLString(valbuf);
+            WMPutInPLDictionary(p, keyProp, valProp);
+            WMReleasePropList(valProp);
         }
 
-        PLRelease(keyProp);
+        WMReleasePropList(keyProp);
     }
 
     return string_found;
@@ -249,10 +249,10 @@ void            saveProperties(allInfo *ai)
 {
     char        buf[256];
     int         cur_mp, i;
-    proplist_t  props;
+    WMPropList *props;
     struct MPInfo  *mp;
 
-    props = PLGetProplistWithPath(getFileName());
+    props = WMReadPropListFromFile(getFileName());
     if (props == NULL)
     {
         static int recursion = 0;
@@ -286,12 +286,12 @@ void            saveProperties(allInfo *ai)
      */
     if (strcmp(icondir, ICONDIR) == 0)
     {
-        proplist_t keyProp;
+        WMPropList *keyProp;
 
-        keyProp = PLMakeString("icondir");
-        if (keyProp && PLGetDictionaryEntry(props, keyProp))
-            PLRemoveDictionaryEntry(props, keyProp);
-        PLRelease(keyProp);
+        keyProp = WMCreatePLString("icondir");
+        if (keyProp && WMGetFromPLDictionary(props, keyProp))
+            WMRemoveFromPLDictionary(props, keyProp);
+        WMReleasePropList(keyProp);
     }
     else
         savePropString(props, "icondir", icondir, STR);
@@ -357,25 +357,26 @@ void            saveProperties(allInfo *ai)
 
     for (cur_mp = 0; cur_mp < ai->numMounts; cur_mp++)
     {
-        proplist_t nameProp, mpProp;
+        WMPropList *nameProp, *mpProp;
 
         mp = ai->mpi[cur_mp];
         sprintf(buf, "mountpoint.%s", mp->mountStr);
 
-        nameProp = PLMakeString(buf);
+        nameProp = WMCreatePLString(buf);
         if (nameProp == NULL)
             continue;
 
-        mpProp = PLGetDictionaryEntry(props, nameProp);
-        if (mpProp && PLIsDictionary(mpProp))
+        mpProp = WMGetFromPLDictionary(props, nameProp);
+        if (mpProp && WMIsPLDictionary(mpProp))
         {
-            PLRemoveDictionaryEntry(props, mpProp);
+            WMRemoveFromPLDictionary(props, nameProp);
         }
         {
-            proplist_t key, value;
+            WMPropList *key, *value;
 
-            key = PLMakeString("mountname"); value = PLMakeString(mp->name);
-            mpProp = PLMakeDictionaryFromEntries(key, value, NULL);
+            key = WMCreatePLString("mountname");
+            value = WMCreatePLString(mp->name);
+            mpProp = WMCreatePLDictionary(key, value, NULL);
         }
 
         switch(mp->icon)
@@ -441,16 +442,16 @@ void            saveProperties(allInfo *ai)
         else
             savePropString(mpProp, "eject", "no", 3);
 
-        PLInsertDictionaryEntry(props, nameProp, mpProp);
+        WMPutInPLDictionary(props, nameProp, mpProp);
 
-        PLRelease(nameProp);
-        PLRelease(mpProp);
+        WMReleasePropList(nameProp);
+        WMReleasePropList(mpProp);
     }
 
-    if (PLSave(props, FALSE) == NO)
+    if (WMWritePropListToFile(props, getFileName(), FALSE) == FALSE)
         printf("Error occurred synchronizing proplist\n");
 
-    PLRelease(props);
+    WMReleasePropList(props);
 }
 
 /*
@@ -528,7 +529,7 @@ int      createDefaultPropertiesFile(allInfo *ai)
         }
     }
 
-    fputs("{ };", fp);
+    fputs("{ }\n", fp);
     fclose(fp);
 
     saveProperties(ai);
